@@ -266,6 +266,7 @@ def render(app, member_def, domain=None, show_define_initializer=False,
     app.config.breathe_separate_member_pages = False
     app.config.breathe_use_project_refids = False
     app.config.breathe_show_define_initializer = show_define_initializer
+    app.config.breathe_order_parameters_first = False
     app.config.breathe_debug_trace_directives = False
     app.config.breathe_debug_trace_doxygen_ids = False
     app.config.breathe_debug_trace_qualification = False
@@ -287,11 +288,21 @@ def test_render_func(app):
                                   param=[WrappedParam(type_=WrappedLinkedText(content_=[WrappedMixedContainer(value=u'int')]))])
     signature = find_node(render(app, member_def), 'desc_signature')
     assert signature.astext().startswith('void')
-    assert find_node(signature, 'desc_name')[0] == 'foo'
+    if sphinx.version_info[0] < 4:
+        assert find_node(signature, 'desc_name')[0] == 'foo'
+    else:
+        n = find_node(signature, 'desc_name')[0]
+        assert isinstance(n, sphinx.addnodes.desc_sig_name)
+        assert len(n) == 1
+        assert n[0] == 'foo'
     params = find_node(signature, 'desc_parameterlist')
     assert len(params) == 1
     param = params[0]
-    assert param[0] == 'int'
+    if sphinx.version_info[0] < 4:
+        assert param[0] == 'int'
+    else:
+        assert isinstance(param[0], sphinx.addnodes.desc_sig_keyword_type)
+        assert param[0][0] == 'int'
 
 
 def test_render_typedef(app):
@@ -311,10 +322,15 @@ def test_render_c_function_typedef(app):
                                   type_='void* (*', name='voidFuncPtr', argsstring=')(float, int)')
     signature = find_node(render(app, member_def, domain='c'), 'desc_signature')
     assert signature.astext().startswith('typedef void *')
-    params = find_node(signature, 'desc_parameterlist')
-    assert len(params) == 2
-    assert params[0].astext() == "float"
-    assert params[1].astext() == "int"
+    if sphinx.version_info[0] < 4:
+        params = find_node(signature, 'desc_parameterlist')
+        assert len(params) == 2
+        assert params[0].astext() == "float"
+        assert params[1].astext() == "int"
+    else:
+        # the use of desc_parameterlist in this case was not correct,
+        # it should only be used for a top-level function
+        pass
 
 
 def test_render_using_alias(app):
@@ -406,7 +422,7 @@ def test_render_innergroup(app):
                                 options=['inner']))
 
 def get_directive(app):
-    from breathe.directives import DoxygenFunctionDirective
+    from breathe.directives.function import DoxygenFunctionDirective
     from breathe.project import ProjectInfoFactory
     from breathe.parser import DoxygenParserFactory
     from breathe.finder.factory import FinderFactory
@@ -457,14 +473,14 @@ def test_resolve_overrides(app):
 
     # Verify that the exact arguments returns one override
     for args in argsstrings:
-        ast_param = cls.parse_args(args)
-        ret = cls.resolve_function(matches, ast_param, None)
+        ast_param = cls._parse_args(args)
+        ret = cls._resolve_function(matches, ast_param, None)
 
 def test_ellipsis(app):
     argsstrings, matches = get_matches('ellipsis.xml')
     cls = get_directive(app)
 
     # Verify that parsing an ellipsis works
-    ast_param = cls.parse_args(argsstrings[0])
-    ret = cls.resolve_function(matches, ast_param, None)
+    ast_param = cls._parse_args(argsstrings[0])
+    ret = cls._resolve_function(matches, ast_param, None)
 
